Client

Struct Client 

pub struct Client { /* private fields */ }
Backend client for Azure Table storage.

Implementations

Source

impl Client

Azure Table Storage management operations (outside the wasi-jsondb trait).

pub async fn ensure_table(&self, table: &str) -> Result<bool>

Creates the named table if it does not already exist.

Returns true when the table was created, false when it already existed.

Errors

Returns an error if the HTTP request fails or the server responds with an unexpected status code.